"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const BPromise = require("bluebird");
const runNewman_1 = require("./lib/runNewman");
const validate_1 = require("./lib/validate");
const writeEnv_1 = require("./lib/writeEnv");
class NewmanPlugin {
    /**
     * Create a new instance.
     *
     * @param {Object} serverless the Serverless instance
     * @param {Object} options    passed in options
     */
    constructor(serverless, options) {
        this.serverless = serverless;
        this.logger = this.serverless.cli;
        this.options = options;
        this.service = this.serverless.service;
        // this.provider = serverless.getProvider('aws');
        if (this.service.custom) {
            this.config = this.service.custom.newman;
        }
        // make sure that we have access to node_modules/.bin services
        // if (process.env.PATH.indexOf('./node_modules/.bin') === -1) {
        //   process.env.PATH = `./node_modules/.bin:${process.env.PATH}`;
        // }
        this.commands = this.defineCommands();
        this.hooks = this.defineHooks();
        // console.log(JSON.stringify(this.serverless.pluginManager.hooks, null, 2));
    }
    defineCommands() {
        const commonOptions = {
            stage: {
                usage: 'Stage of the service',
                shortcut: 's',
            },
            region: {
                usage: 'Region of the service',
                shortcut: 'r',
            },
            verbose: {
                usage: 'Show all stack events during deployment',
                shortcut: 'v',
            },
        };
        return {
            newman: {
                commands: {
                    env: {
                        usage: 'Write the postman environment file',
                        lifecycleEvents: ['init', 'newman', 'env'],
                        options: commonOptions,
                    },
                    run: {
                        usage: 'Runs newman tests',
                        lifecycleEvents: ['init', 'newman', 'run'],
                        options: commonOptions,
                    },
                },
            },
        };
    }
    defineHooks() {
        return {
            'newman:env:init': () => BPromise.bind(this)
                .then(validate_1.validate)
                .then(writeEnv_1.writeEnv),
            'newman:run:init': () => BPromise.bind(this)
                .then(validate_1.validate)
                .then(runNewman_1.runNewman),
        };
    }
}
exports.default = NewmanPlugin;
