"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_promise_1 = require("child-process-promise");
const fs = require("fs-extra");
const Path = require("path");
const logger = console;
/**
 * Retrieves stack Ouputs from AWS.
 *
 * @returns {undefined}
 */
function runNewman() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            this.logger.log('Running Newman...');
            if (!this.config.environment) {
                this.logger.log('No Newman Environment Configuration Found. Proceeding with tests');
                return;
            }
            const collection = this.config.collection;
            const environment = this.config.environment || '';
            if (!collection.file) {
                this.logger.log('No `newman.collection.json` defined. Exiting Newman.');
                return;
            }
            const absoluteCollectionPath = Path.resolve(`${process.cwd()}/${collection.file}`);
            const absoluteEnvironmentPath = Path.resolve(`${process.cwd()}/${environment.file}`);
            const spawnArgs = ['run', absoluteCollectionPath];
            if (fs.existsSync(absoluteEnvironmentPath)) {
                spawnArgs.push('-e');
                spawnArgs.push(absoluteEnvironmentPath);
            }
            const promise = child_process_promise_1.spawn('newman', spawnArgs);
            const child = promise.childProcess;
            child.stdout.on('data', (data) => {
                logger.log(data.toString());
            });
            child.stderr.on('data', (data) => {
                logger.log(data.toString());
            });
            yield promise;
        }
        catch (error) {
            this.logger.log(error);
            throw error;
        }
    });
}
exports.runNewman = runNewman;
