"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const types_1 = require("../types");
/**
 * Get the env file template.
 *
 * @param {String} name the service name
 *
 * @returns {IEnvFile} the env file
 */
function getEnvTemplate(name) {
    return {
        name,
        values: [],
        _postman_variable_scope: 'environment',
    };
}
function writeEnv() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            this.logger.log('Writing postman_environment.json file...');
            const outputs = yield fs.readJson(`${process.cwd()}/.serverless/stack-outputs.json`);
            const config = this.config;
            const envFilePath = this.config.environment.file;
            const envFile = getEnvTemplate(this.serverless.service.service);
            config.environment.values.forEach((value) => {
                if (!value.enabled) {
                    return;
                }
                if (value.type === types_1.ValueType.OUTPUTS) {
                    value.value = outputs[value.value];
                }
                else if (value.type === types_1.ValueType.ENVIRONMENT) {
                    value.value = process.env[value.value];
                }
                delete value.type;
                envFile.values.push(value);
            });
            yield fs.writeJson(envFilePath, envFile, { spaces: 2 });
        }
        catch (error) {
            this.logger.log(error);
            throw error;
        }
    });
}
exports.writeEnv = writeEnv;
